function port = port_open(pname)
%Opens the PIC32 communication serial port.
%   The name of the port is stored in settings.txt.  If that file does not exist, the
%   user will be prompted to enter a serial port name
%
%   port = port_open()
%   port = port_open(pname)
%
%   Input Arguments:
%       pname - the name of the serial port. If omitted the file
%              settings.txt will be queried. If it does not exist the user
%              will be prompted
%   Output Arguments:
%       The name of the serial port.
    SETTINGS_FILE = 'settings.txt';
    BAUD = 230400;
    nin = nargin;
    
    if nin == 0
        if exist(SETTINGS_FILE,'file') ~= 2
            prompt = sprintf('Enter the NU32 communication serial port (i.e ');
            if isunix()
                prompt = [prompt, sprintf('/dev/ttyUSBx')];
            elseif ismac()
                prompt = [prompt, sprintf('/dev/tty.usbserial-xxxxxxxx')];
            elseif ispc()
                prompt = [prompt, sprintf('COMx')];
            end
            prompt = [prompt, sprintf('): ')];
            pname = input(prompt,'s');
        else
            f = fopen(SETTINGS_FILE,'r');
            pname = fscanf(f,'%s');
            fclose(f);
        end
    end

    %write the name to the file
   f = fopen(SETTINGS_FILE,'w');
   fprintf(f,pname);
   fclose(f);
   
    if ~isempty(instrfind)
        fclose(instrfind);
        delete(instrfind);
    end
    if strcmp(pname,'1') %allow for debugging by writing data to console
        port = 1;
    else
        port = serial(pname, 'BaudRate', BAUD, 'FlowControl', 'hardware');
        fopen(port);
    end
end