function menu = make_menu(title,entries,options_entries,onquit)
% Makes a text based menu
%
%   menu = make_menu(title,entries)
%   menu = make_menu(title,entries,options_entries)
%
%   Input Arguments:
%       title   - the name of the menu
%       entries - cell array of menu_entries.  These are made by calling
%                 make_entry
%       options_entries (optional) - cell array of entries for options, made with
%                                   make_option
%       onquit (optional) - function to be called on quit
%                              onquit(menu.options)
%   Output Arguments:
%       menu - A text based menu that can be executed by running run_menu()
%       menu has the following fields
%       menu.(cmd) - one entry for every command
%       menu.entries - the original entries cell array
%       menu.sub_cmd - used for storing parent menus.  
%       menu.title - the name of the menu
   nin = nargin;
   if nin < 3
       options_entries = {};
   end
   if nin < 4
       onquit = @(x)x;
   end
   
   
    used_entries = cell(1,length(entries));
    for i=1:length(entries)
        used_entries{i} = 'q';
    end
    menu.entries = entries;
    
    %set the options menu
    if ~isempty(options_entries)
        options = make_menu('Options',options_entries);
        menu.options_menu = options;   
        %set the default options
        for i=1:length(options.entries)
            menu.options.(options.entries{i}.name) = options.entries{i}.default;
        end
    else
        menu.options_menu = {};
        menu.options = {};
    end
    for i=1:length(entries)
        cmd = entries{i}.cmd;
        if ismember(cmd,used_entries)
            error(['make_menu:dup duplicate menu entry value ''',cmd,'''']);
        end
        used_entries{i} = cmd;
        menu.(cmd) = entries{i};
    end   
    menu.sub_cmd = '';
    menu.flat = false;
    menu.title = title;
    menu.options_menu.parent = menu;
    menu.onquit = onquit;
end