function status = run_menu(menu,times)
% This displays the menu to the user
%
%   status = run_menu(menu)
%   status = run_menu(menu,times)
%
%   Input Arguments:
%       menu - a menu created with make_menu
%       times - (optional) the number of times to cycle through the menu before
%               quitting.  If blank, defaults to infinite

%
%   Output Arguments:
%       status - the status of the last command, or blank if its menu
%                 action does not return a value
    nin = nargin;
    if nin < 2
        times = inf;
    end
    
    selection = ' ';
    status = [];
    while selection ~= 'q' && times > 0
        times = times - 1;
        try
             fprintf('\n%s:\n',menu.title);
            if ~menu.flat               
                for i = 1:length(menu.entries)   %print out the menu entries
                    disp([' ',menu.entries{i}.cmd,': ',menu.entries{i}.description]);
                end
                disp(' q: Quit');
            else
                % print the flat menu
                for i = 1:length(menu.lines)
                    disp(menu.lines{i});
                end
            end
            fprintf('\n');
            selection = input('What Do You Want? ','s'); % prompt the user
            if menu.flat %if we are using a flat menu, translate the user selection
                         %into a selection that would not be flat
                         %this also turns the current menu object into the
                         %appropriate submenu
                [selection, menu] = menu.translate(selection);
            end
            disp('------------------------------------------');
            if selection == 'q'
                disp('Goodbye!');
                status = 'q';
            elseif selection == 'o' && ~isempty(menu.options_menu)
                quit_options = false;
                while ~quit_options
                    ret = run_menu(menu.options_menu,1);
                    if isfield(ret,'value')
                        menu.options.(ret.name).value = ret.value;
                        menu.options.(ret.name).str = ret.str;
                        menu.options_menu.parent = menu;
                    else
                        quit_options = true;
                    end
                end
                status = 'o';
            elseif isfield(menu,selection)
                action = menu.(selection).action;
                if nargout(action) > 0
                    status = action(menu,selection,menu.(selection).args{:});
                else
                    action(menu,selection,menu.(selection).args{:});
                    status = [];
                end
            else
                disp(['I Don''t Know How To ''',selection,'''. Please Try Again.']);
            end
            disp('------------------------------------------');
        catch err
            fprintf('Error %s\n',err.message);
        end
    end
    menu.onquit(menu.options);
end