function [data, handles] = control_plot(menu,cmd,port,nsamples)  
% Plots the control results from the pic
%
%   control_plot(menu,cmd,port)
%   control_port(menu,cmd,port,nsamples)
%
%   Input Arguments:
%       menu - the menu that led to this function being called
%       cmd  - the specific command that led to this function being called
%       port - the serial port
%       nsamples (optional) - See pic_plot.m
%   Output Arguments:
%       data    - the data that was retrieved
%       handles - cell array handles to the plots that were created
%   Data will be plotted in the current figure
    nin = nargin;
    if nin < 4
        nsamples = {};
    else
        nsamples = {nsamples};
    end
    [data,handles] = pic_plot(menu,cmd,port,'%d %d %d',nsamples{:});
    rmenu = root_menu(menu);
    if strcmpi(rmenu.options.show_u.value,'n')
        set(handles{3},'Visible','off');
        legend('r','y');
    else
        legend('r','y','u');
    end
    
    %  sum of square error
    error = sqrt(double(sum((data(1,:) - data(2,:)).^2)));
    % sum of square control effort
    u = sqrt(double(sum(data(3,:)).^2));
    
    score = error + u/1000;
    fprintf('Error %0.1f,   Control Effort:   %0.1f Score:   %0.1f\n',...
        error,u,score);
    
end